Mediate.PolicyVersion (mediate v0.1.0)

Copy Markdown View Source

One published version of an adapter's rules. content holds the text by value when it is under the configured cap. Otherwise pointer names where the text lives. A decision record carries only the version identifier.

Summary

Types

The version identifier a decision record carries: a commit, a migration number, or a model id.

t()

One published version, as the policy-version event carries it.

Types

ref()

@type ref() :: String.t()

The version identifier a decision record carries: a commit, a migration number, or a model id.

t()

@type t() :: %Mediate.PolicyVersion{
  adapter: module(),
  approval: String.t(),
  at: DateTime.t(),
  author: String.t(),
  content: String.t() | nil,
  content_hash: String.t(),
  pointer: String.t() | nil,
  version: ref()
}

One published version, as the policy-version event carries it.